# Contributor Guide

Guidelines for contributing to ani-scrapy.

## Contents

| # | Document | Description |
|---|----------|-------------|
| 01 | [01_contributing.md](./01_contributing.md) | Setup, code style, conventions |
| 02 | [02_adding_scrapers.md](./02_adding_scrapers.md) | Adding new scrapers |
| 03 | [03_testing.md](./03_testing.md) | Testing philosophy and guidelines |

## Quick Links

### Getting Started

- [Setup and Code Style](./01_contributing.md)
- [Testing Guidelines](./03_testing.md)

### Extending

- [Adding New Scrapers](./02_adding_scrapers.md)
